psychopy_ext.exp.Task.check_continue — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.check_continue

`Task.` `check_continue`()

  Check if the event is not over yet.

  Uses `event_clock`, `trial_clock`, and, if `self.global_timing` is True, `glob_clock` to check whether the current event is not over yet. The event cannot last longer than event and trial durations and also fall out of sync from global clock.

  Returns: | A list of tuples with a key name (str) and a response time (float).